==> 1.9.2.tar.gz: android/src/main/java/com/enx_plugin/enx_flutter_plugin/EnxUtils.java <==
package com.enx_plugin.enx_flutter_plugin;

import android.util.Log;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public final class EnxUtils {

    /**
     * Function Name :- jsonToMap
     * Function Description:- used to get Hashmap of String type using jSONObject
     * Input type:- JSONObject
     * Return Type:- HashMap<String, String>
     */

    protected static HashMap<String, Object> jsonToMap(JSONObject json) throws JSONException {
        HashMap<String, Object> retMap = new HashMap<String, Object>();

        if (json != JSONObject.NULL) {
            retMap = toMap(json);
        }
        Log.e("jsonToMap", retMap.toString());
        return retMap;
    }

    protected static HashMap<String, Object> toMap(JSONObject object) throws JSONException {
        HashMap<String, Object> map = new HashMap<String, Object>();

        Iterator<String> keysItr = object.keys();
        while (keysItr.hasNext()) {
            String key = keysItr.next();
            Object value = object.get(key);

            if (value instanceof JSONArray) {
                value = toList((JSONArray) value);
            } else if (value instanceof JSONObject) {
                value = toMap((JSONObject) value);
            }
            map.put(key, value);
        }
        return map;
    }

    protected static ArrayList<Object> toList(JSONArray array) throws JSONException {
        ArrayList<Object> list = new ArrayList<Object>();
        for (int i = 0; i < array.length(); i++) {
            Object value = array.get(i);
            if (value instanceof JSONArray) {
                value = toList((JSONArray) value);
            } else if (value instanceof JSONObject) {
                value = toMap((JSONObject) value);
            }
            list.add(value);
        }
        return list;
    }

    protected static JSONObject convertMapToJson(Map<String, Object> map) throws JSONException {
        JSONObject jsonData = new JSONObject();
        for (String key : map.keySet()) {
            Object value = map.get(key);
            if (value instanceof Map<?, ?>) {
                value = convertMapToJson((Map<String, Object>) value);
            }
            jsonData.put(key, value);
        }
        return jsonData;
    }
}

==> 2.3.10.tar.gz: android/src/main/java/com/enx_plugin/enx_flutter_plugin/EnxUtils.java <==
package com.enx_plugin.enx_flutter_plugin;

import android.util.Log;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public final class EnxUtils {

    /**
     * Function Name :- jsonToMap
     * Function Description:- used to get Hashmap of String type using jSONObject
     * Input type:- JSONObject
     * Return Type:- HashMap<String, String>
     */

    protected static HashMap<String, Object> jsonToMap(JSONObject json) throws JSONException {
        HashMap<String, Object> retMap = new HashMap<String, Object>();

        if (json != JSONObject.NULL) {
            retMap = toMap(json);
        }
        Log.e("jsonToMap", retMap.toString());
        return retMap;
    }

    protected static HashMap<String, Object> toMap(JSONObject object) throws JSONException {
        HashMap<String, Object> map = new HashMap<String, Object>();

        Iterator<String> keysItr = object.keys();
        while (keysItr.hasNext()) {
            String key = keysItr.next();
            Object value = object.get(key);

            if (value instanceof JSONArray) {
                value = toList((JSONArray) value);
            } else if (value instanceof JSONObject) {
                value = toMap((JSONObject) value);
            }
            map.put(key, value);
        }
        return map;
    }

    protected static ArrayList<Object> toList(JSONArray array) throws JSONException {
        ArrayList<Object> list = new ArrayList<Object>();
        for (int i = 0; i < array.length(); i++) {
            Object value = array.get(i);
            if (value instanceof JSONArray) {
                value = toList((JSONArray) value);
            } else if (value instanceof JSONObject) {
                value = toMap((JSONObject) value);
            }
            list.add(value);
        }
        return list;
    }

    protected static JSONObject convertMapToJson(Map<String, Object> map) throws JSONException {
        JSONObject jsonData =  new JSONObject(map);;

      /*  for (String key : map.keySet()) {
            Object value = map.get(key);
            if (value instanceof Map<?, ?>) {
                value = convertMapToJson((Map<String, Object>) value);
            }
            jsonData.put(key, value);
        }*/
        return jsonData;
    }
}
